[interchange] change $ENV{MINIVEND_PORT} to 7786 instead of 8786.

Gert van der Spoel <[email protected]>
Newsgroups gmane.comp.web.interchange.cvs
Message-ID <[email protected]>
commit 8cad9a8e944ce9b77882cf1be7ab248670f2d855
Author: Gert van der Spoel <[email protected]>
Date:   Wed Dec 30 19:29:19 2009 +0100

    change $ENV{MINIVEND_PORT} to 7786 instead of 8786.
    
    Standard listening on port 7786 (decimal M (77), decimal V (86).
    Makes sense to, by default, test with that portnumber.

 test.pl |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/test.pl b/test.pl
index 0608b2f..e00604b 100644
--- a/test.pl
+++ b/test.pl
@@ -33,7 +33,7 @@ die "Must be in build directory\n" unless -d 'blib';
 die "No tests defined for Windows\n" if $^O =~ /win32/i;
 
 $ENV{MINIVEND_ROOT} = "$cur_dir/blib";
-$ENV{MINIVEND_PORT} = 8786 unless defined $ENV{MINIVEND_PORT};
+$ENV{MINIVEND_PORT} = 7786 unless defined $ENV{MINIVEND_PORT};
 
 my $extra_cfg = '';
 
@@ -217,7 +217,7 @@ else {
 	print <<EOF;
 
 # When the above test fails, it may be due to your ISP or some other
 # mechanism blocking port 8786.
 
 EOF
 	$failed++;
@@ -217,7 +217,7 @@ else {
 
 # When the above test fails, it may be due to your ISP or some other
-# mechanism blocking port 8786.
+# mechanism blocking port 7786.
 
 EOF
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.